Bifrost: Data Fields

Bifrost

Here is a list of all documented struct and union fields with links to the struct/union documentation for each field:

### - b -

- backwardBase() : Kmer
- BackwardCDBG() : BackwardCDBG< Unitig_data_t, Graph_data_t, is_const >
- begin() : BackwardCDBG< Unitig_data_t, Graph_data_t, is_const > , CompactedDBG< Unitig_data_t, Graph_data_t > , ForwardCDBG< Unitig_data_t, Graph_data_t, is_const > , UnitigColors
- build : CDBG_Build_opt , CompactedDBG< Unitig_data_t, Graph_data_t >
- buildColors() : ColoredCDBG< Unitig_data_t >
- buildGraph() : ColoredCDBG< Unitig_data_t >